Bug 1369831 - fix "telementry" typo in js; r?billm draft
authorTom Tromey <tom@tromey.com>
Fri, 02 Jun 2017 12:49:56 -0600
changeset 588408 cba2a9fd5af9d6c78eceeef33cf4fd5204b3c8fb
parent 588407 51287feb0445ee7b5f58c947fa1392fbb4af0e16
child 631564 186d43b80f4a7b1e02a64151a9b651b0d2c2ca86
push id62024
push userbmo:ttromey@mozilla.com
push dateFri, 02 Jun 2017 19:41:37 +0000
reviewersbillm
bugs1369831
milestone55.0a1
Bug 1369831 - fix "telementry" typo in js; r?billm MozReview-Commit-ID: DxhNlSnvZZC
js/src/jsexn.cpp
js/src/jsfriendapi.h
--- a/js/src/jsexn.cpp
+++ b/js/src/jsexn.cpp
@@ -784,17 +784,17 @@ ErrorReport::ErrorReport(JSContext* cx)
 {
 }
 
 ErrorReport::~ErrorReport()
 {
 }
 
 void
-ErrorReport::ReportAddonExceptionToTelementry(JSContext* cx)
+ErrorReport::ReportAddonExceptionToTelemetry(JSContext* cx)
 {
     MOZ_ASSERT(exnObject);
     RootedObject unwrapped(cx, UncheckedUnwrap(exnObject));
     MOZ_ASSERT(unwrapped, "UncheckedUnwrap failed?");
 
     // There is not much we can report if the exception is not an ErrorObject, let's ignore those.
     if (!unwrapped->is<ErrorObject>())
         return;
@@ -864,18 +864,18 @@ ErrorReport::init(JSContext* cx, HandleV
 
         if (!reportp && sniffingBehavior == NoSideEffects) {
             JS_ReportErrorNumberASCII(cx, GetErrorMessage, nullptr,
                                       JSMSG_ERR_DURING_THROW);
             return false;
         }
 
         // Let's see if the exception is from add-on code, if so, it should be reported
-        // to telementry.
-        ReportAddonExceptionToTelementry(cx);
+        // to telemetry.
+        ReportAddonExceptionToTelemetry(cx);
     }
 
 
     // Be careful not to invoke ToString if we've already successfully extracted
     // an error report, since the exception might be wrapped in a security
     // wrapper, and ToString-ing it might throw.
     if (reportp) {
         str = ErrorReportToString(cx, reportp);
--- a/js/src/jsfriendapi.h
+++ b/js/src/jsfriendapi.h
@@ -1477,18 +1477,18 @@ struct MOZ_STACK_CLASS JS_FRIEND_API(Err
     // but fills in an ErrorReport instead of reporting it.  Uses varargs to
     // make it simpler to call js::ExpandErrorArgumentsVA.
     //
     // Returns false if we fail to actually populate the ErrorReport
     // for some reason (probably out of memory).
     bool populateUncaughtExceptionReportUTF8(JSContext* cx, ...);
     bool populateUncaughtExceptionReportUTF8VA(JSContext* cx, va_list ap);
 
-    // Reports exceptions from add-on scopes to telementry.
-    void ReportAddonExceptionToTelementry(JSContext* cx);
+    // Reports exceptions from add-on scopes to telemetry.
+    void ReportAddonExceptionToTelemetry(JSContext* cx);
 
     // We may have a provided JSErrorReport, so need a way to represent that.
     JSErrorReport* reportp;
 
     // Or we may need to synthesize a JSErrorReport one of our own.
     JSErrorReport ownedReport;
 
     // And we have a string to maybe keep alive that has pointers into